@@ -5,12 +5,11 @@ package Util::Underscore;
 use strict;
 use warnings;
 
-use version 0.77; our $VERSION = qv('v1.3.0');
+use version 0.77; our $VERSION = qv('v1.4.0');
 use overload ();
 
 use Carp ();
 use Const::Fast 0.011    ();
-use Data::Alias 1.18     ();
 use Data::Dump 1.10      ();
 use List::MoreUtils 0.07 ();
 use List::Util 1.35      ();
@@ -195,12 +194,12 @@ Util::Underscore - Common helper functions without having to import them
 
 =head1 VERSION
 
-version v1.3.0
+version v1.4.0
 
 =head1 SYNOPSIS
 
     use Util::Underscore;
-    
+
     _::croak "$foo must do Some::Role" if not _::does($foo, 'Some::Role');
 
 =head1 DESCRIPTION
@@ -231,7 +230,7 @@ The function reference is split into separate topics which each have their own d
 
 see L<Util::Underscore::Scalars|Util::Underscore::Scalars>
 
-C<alias>,
+C<alias>(*),
 C<const>,
 C<is_dual>,
 C<is_identifier>,
@@ -246,6 +245,8 @@ C<new_dual>,
 C<chomp>,
 C<index>
 
+(*) if L<Data::Alias|Data::Alias> is installed.
+
 =item Numbers
 
 see L<Util::Underscore::Numbers|Util::Underscore::Numbers>
@@ -357,10 +358,10 @@ The functions C<_::carp>, C<_::cluck>, C<_::croak>, and C<_::confess> from the C
 They all take a list of strings as argument.
 How do they differ from each other?
 
-    Stack Trace || Fatal    | Warning
-    ------------##====================
-        No      || croak    | carp
-        Yes     || confess  | cluck
+    Fatal   Warning
+    ------- ------- ---------------------
+    croak   carp    from call location
+    confess cluck   with full stack trace
 
 How do they differ from Perl's builtin C<die> and C<warn>?
 The error messages of C<die> and C<warn> are located on the line where the exception is raised.
@@ -450,8 +451,9 @@ If ommited, uses C<1>.
 B<returns>:
 A list of C<Util::Underscore::CallStackFrame> objects.
 
-=C<$stack_frame = _::caller>
-=C<$stack_frame = _::caller $level>
+=item C<$stack_frame = _::caller>
+
+=item C<$stack_frame = _::caller $level>
 
 Assembles an object representing a specific call stack frame.
 
@@ -466,7 +468,7 @@ If no such frame exists, C<undef> is returned.
 
 =back
 
-For invoking external commands, Perl offers the C<sytem> command, various modes for C<open>, and the backtick operator (C<qx//>).
+For invoking external commands, Perl offers the C<system> command, various modes for C<open>, and the backtick operator (C<qx//>).
 However, these modes encourage interpolating variables directly into a string, which opens up shell injection issues.
 In fact, C<open> and C<system> can't avoid shell injection when piping or redirection is involved.
 The L<IPC::Run|IPC::Run> module avoids this by offering a flexible interface for launching and controlling external processes.
@@ -487,7 +489,7 @@ This is inverse to Perl's built in C<system> function!
 Example:
 
     my $data = "stuff you want to display with a pager.";
-    
+
     # The contents of $data are entered via STDIN
     _::process_run ['less', '-R'], \$data
         or die "Couldn't run less: $?";
@@ -560,7 +562,7 @@ L<Safe::Isa|Safe::Isa>.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/latk/p5-Util-Underscore/issues
+L<https://github.com/latk/p5-Util-Underscore/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -578,7 +580,7 @@ Olivier Mengué (cpan: DOLMEN) <dolmen@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Lukas Atkinson.
+This software is copyright (c) 2017 by Lukas Atkinson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
