@@ -52,7 +52,7 @@ Util::Underscore::Numbers - Functions for dealing with numbers
 
 =head1 VERSION
 
-version v1.3.0
+version v1.4.0
 
 =head1 FUNCTION REFERENCE
 
@@ -139,7 +139,7 @@ If the C<$float> is not a finite number (i.e. infinite or NaN), then that input
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/latk/p5-Util-Underscore/issues
+L<https://github.com/latk/p5-Util-Underscore/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -151,7 +151,7 @@ Lukas Atkinson (cpan: AMON) <amon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Lukas Atkinson.
+This software is copyright (c) 2017 by Lukas Atkinson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
